==> collective.contract_management-1.0b2.tar.gz: collective.contract_management-1.0b2/src/collective/contract_management/vocabularies/renewal_periods.py <==
# -*- coding: utf-8 -*-

# from plone import api
from collective.contract_management import _
from plone.dexterity.interfaces import IDexterityContent
from zope.globalrequest import getRequest
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


class VocabItem(object):
    def __init__(self, token, value):
        self.token = token
        self.value = value


@implementer(IVocabularyFactory)
class RenewalPeriods(object):
    """
    """

    def __call__(self, context):
        # Just an example list of content for our vocabulary,
        # this can be any static or dynamic data, a catalog result for example.
        items = [
            VocabItem(u'3', _(u'3 months')),
            VocabItem(u'6', _(u'6 months')),
            VocabItem(u'12', _(u'12 months')),
            VocabItem(u'24', _(u'24 months')),
            VocabItem(u'36', _(u'36 months')),
        ]

        # Fix context if you are using the vocabulary in DataGridField.
        # See https://github.com/collective/collective.z3cform.datagridfield/issues/31:  # NOQA: 501
        if not IDexterityContent.providedBy(context):
            req = getRequest()
            context = req.PARENTS[0]

        # create a list of SimpleTerm items:
        terms = []
        for item in items:
            terms.append(
                SimpleTerm(
                    value=item.token,
                    token=str(item.token),
                    title=item.value,
                )
            )
        # Create a SimpleVocabulary from the terms list and return it:
        return SimpleVocabulary(terms)


RenewalPeriodsFactory = RenewalPeriods()

==> collective.contract_management-2.0b4.tar.gz: collective.contract_management-2.0b4/src/collective/contract_management/vocabularies/renewal_periods.py <==
# -*- coding: utf-8 -*-

# from plone import api
from collective.contract_management import _
from plone.dexterity.interfaces import IDexterityContent
from zope.globalrequest import getRequest
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary


class VocabItem(object):
    def __init__(self, token, value):
        self.token = token
        self.value = value


@implementer(IVocabularyFactory)
class RenewalPeriods(object):
    """
    """

    def __call__(self, context):
        # Just an example list of content for our vocabulary,
        # this can be any static or dynamic data, a catalog result for example.
        items = [
            VocabItem(u"3", _(u"3 months")),
            VocabItem(u"6", _(u"6 months")),
            VocabItem(u"12", _(u"12 months")),
            VocabItem(u"24", _(u"24 months")),
            VocabItem(u"36", _(u"36 months")),
        ]

        # Fix context if you are using the vocabulary in DataGridField.
        # See https://github.com/collective/collective.z3cform.datagridfield/issues/31:  # NOQA: 501
        if not IDexterityContent.providedBy(context):
            req = getRequest()
            context = req.PARENTS[0]

        # create a list of SimpleTerm items:
        terms = []
        for item in items:
            terms.append(
                SimpleTerm(value=item.token, token=str(item.token), title=item.value)
            )
        # Create a SimpleVocabulary from the terms list and return it:
        return SimpleVocabulary(terms)


RenewalPeriodsFactory = RenewalPeriods()
